@@ -17,17 +17,24 @@
     along with this program.  If not, see <http://www.gnu.org/licenses/>.
 """
 
+
 def unprovide():
-    print "ERROR: This feature does not provide"
-    exit(10)    
+    print("ERROR: This feature does not provide")
+    exit(10)
+
 
 def tonicDNSClient(uri, method, token, data):
-    import json, urllib2
+    import sys
+    import json
+    if sys.version_info > (2, 6) and sys.version_info < (2, 8):
+        import urllib2 as urllib
+    elif sys.version_info > (3, 0):
+        import urllib.request as urllib
 
     encoded = json.JSONEncoder().encode(data)
 
-    o = urllib2.build_opener(urllib2.HTTPHandler)
-    r = urllib2.Request(uri, data=encoded)
+    o = urllib.build_opener(urllib.HTTPHandler)
+    r = urllib.Request(uri, data=encoded.encode('utf-8'))
 
     r.add_header('x-authentication-token', token)
 
@@ -40,12 +47,13 @@ def tonicDNSClient(uri, method, token, data):
 
     # response body
     if method == 'GET':
-        datas = json.loads(url.read())
-        print json.dumps(datas, sort_keys=True, indent=2)
-            
+        datas = json.loads(url.read().decode('utf-8'))
+        print(json.dumps(datas, sort_keys=True, indent=2))
+
     else:
         data = url.read()
-        print data
+        print(data)
+
 
 def createZoneRecords():
     # ContentType: application/json
@@ -54,13 +62,15 @@ def createZoneRecords():
     # uri: /zone
     unprovide()
 
+
 def createRecords(server, token, domain, data):
     # ContentType: application/json
     # x-authentication-token: token
     method = 'PUT'
     uri = 'https://' + server + '/zone/' + domain
     tonicDNSClient(uri, method, token, data)
-    
+
+
 def deleteRecords(server, token, data):
     # ContentType: application/json
     # x-authentication-token: token
@@ -68,12 +78,14 @@ def deleteRecords(server, token, data):
     uri = 'https://' + server + '/zone'
     tonicDNSClient(uri, method, token, data)
 
+
 def getZone(server, token, domain):
     # x-authentication-token: token
     method = 'GET'
     uri = 'https://' + server + '/zone/' + domain
     tonicDNSClient(uri, method, token, data=False)
 
+
 def getAllZone(server, token):
     # x-authentication-token: token
     method = 'GET'
@@ -87,6 +99,7 @@ def deleteDomain():
     # uri: /zone/:domain
     unprovide()
 
+
 def createTemplate():
     # ContentType: application/json
     # x-authentication-token: token
@@ -94,6 +107,7 @@ def createTemplate():
     # uri: /template/:template
     unprovide()
 
+
 def updateTemplate():
     # ContentType: application/json
     # x-authentication-token: token
@@ -101,22 +115,23 @@ def updateTemplate():
     # uri: /template
     unprovide()
 
+
 def deleteTemplate():
     # x-authentication-token: token
     # method: DELETE
     # uri: /template/:template
     unprovide()
 
+
 def getTemplate():
     # x-authentication-token: token
     # method: GET
     # uri: /template/:template
     unprovide()
 
+
 def getAllTemplates():
     # x-authentication-token: token
     # method: GET
     # uri: /template
     unprovide()
-
-        
